import time
import uuid
from typing import Dict, Optional

import grpc
from _qwak_proto.qwak.feature_store.sources.data_source_pb2 import (
    DataSource,
    DataSourceDefinition,
    DataSourceMetadata,
    DataSourceSpec,
    FeatureSetBrief,
)
from _qwak_proto.qwak.feature_store.sources.data_source_service_pb2 import (
    CreateDataSourceResponse,
    CreateDataSourceUploadURLRequest,
    CreateDataSourceUploadURLResponse,
    DeleteDataSourceResponse,
    GetDataSourceByIdRequest,
    GetDataSourceByIdResponse,
    GetDataSourceByNameResponse,
    ListDataSourcesResponse,
)
from _qwak_proto.qwak.feature_store.sources.data_source_service_pb2_grpc import (
    DataSourceServiceServicer,
)
from _qwak_proto.qwak.feature_store.v1.internal.data_source.data_source_service_pb2 import (
    GetDataSourceSourceCodeUploadResponse,
)


class DataSourceServiceMock(DataSourceServiceServicer):
    def __init__(self):
        self._data_sources_spec: Dict[str, DataSourceSpec] = {}
        self._data_source_id_to_name: Dict[str, str] = {}
        self._ds_definition_by_name: Dict[str, DataSourceDefinition] = {}

    def CreateDataSource(self, request, context):
        data_source_type = request.data_source_spec.WhichOneof("type")
        data_source_id = str(uuid.uuid4())

        ds_name = (
            request.data_source_spec.batch_source.name
            if data_source_type == "batch_source"
            else request.data_source_spec.stream_source.name
        )
        data_source_definition = DataSourceDefinition(
            data_source_id=data_source_id,
            data_source_spec=request.data_source_spec,
        )

        self._data_sources_spec[ds_name] = request.data_source_spec
        self._data_source_id_to_name[data_source_id] = ds_name
        self._ds_definition_by_name[ds_name] = data_source_definition

        return CreateDataSourceResponse(
            data_source=DataSource(
                data_source_definition=data_source_definition,
                metadata=None,
                feature_sets=[],
            )
        )

    def GetDataSourceByName(self, request, context):
        if request.data_source_name not in self._data_sources_spec:
            context.set_code(grpc.StatusCode.NOT_FOUND)
            return GetDataSourceByNameResponse()

        return GetDataSourceByNameResponse(
            data_source=DataSource(
                data_source_definition=DataSourceDefinition(
                    data_source_id="123",
                    data_source_spec=self._data_sources_spec[request.data_source_name],
                ),
                metadata=None,
                feature_sets=[],
            )
        )

    def GetDataSourceById(self, request: GetDataSourceByIdRequest, context):
        if request.data_source_id not in self._data_source_id_to_name:
            context.set_code(grpc.StatusCode.NOT_FOUND)
            return GetDataSourceByIdResponse()

        data_source_name = self._data_source_id_to_name[request.data_source_id]
        data_source_spec = self._data_sources_spec[data_source_name]

        return GetDataSourceByIdResponse(
            data_source=DataSource(
                data_source_definition=DataSourceDefinition(
                    data_source_id=request.data_source_id,
                    data_source_spec=data_source_spec,
                ),
                metadata=None,
                feature_sets=[],
            )
        )

    def CreateDataSourceUploadURLV1(
        self, request: CreateDataSourceUploadURLRequest, context
    ):
        return CreateDataSourceUploadURLResponse(
            upload_url=f"https://data_source_artifacts.s3.amazonaws.com/{request.data_source_name}_{request.object_name}_{int(time.time() * 1000)}"
        )

    def GetDataSourceSourceCodeUploadURL(self, request, context):
        if request.data_source_name not in self._data_sources_spec:
            context.set_code(grpc.StatusCode.NOT_FOUND)
            return GetDataSourceByNameResponse()

        return GetDataSourceSourceCodeUploadResponse(
            upload_url=f"https://data_source_artifacts.s3.amazonaws.com/{request.data_source_name}_{request.object_name}_{int(time.time() * 1000)}",
            extra_headers={},
        )

    def ListDataSources(self, request, context):
        return ListDataSourcesResponse(
            data_sources=[
                DataSource(
                    data_source_definition=ds_definition,
                    metadata=DataSourceMetadata(),
                    feature_sets=[FeatureSetBrief()],
                )
                for ds_definition in self._ds_definition_by_name.values()
            ]
        )

    def DeleteDataSource(self, request, context):
        ds_name: Optional[str] = self._data_source_id_to_name.get(
            request.data_source_id, None
        )
        if not ds_name:
            context.set_details(
                f"DataSource ID {request.data_source_id} doesn't exist'"
            )
            context.set_code(grpc.StatusCode.NOT_FOUND)

        self._data_sources_spec.pop(ds_name)
        self._data_source_id_to_name.pop(request.data_source_id)
        self._ds_definition_by_name.pop(ds_name)
        return DeleteDataSourceResponse()



from abc import abstractmethod

from qwak.model.schema import ModelSchema


class QwakModel:
    """
    Base class for all Qwak based models
    """

    @abstractmethod
    def build(self):
        """
        Responsible for loading the model. This method is invoked during build time (qwak build command)

        Example usage:

        >>> def build(self):
        >>>     ...
        >>>     train_pool = Pool(X_train, y_train, cat_features=categorical_features_indices)
        >>>     validate_pool = Pool(X_validation, y_validation, cat_features=categorical_features_indices)
        >>>     self.catboost.fit(train_pool, eval_set=validate_pool)

        :return:
        """
        raise ValueError("Please implement build method")

    @abstractmethod
    def predict(self, df):
        """
        Invoked on every API inference request.
        :param df: the inference vector, as a pandas dataframe

        Example usage:

        >>> def predict(self, df) -> pd.DataFrame:
        >>>     return pd.DataFrame(self.catboost.predict(df), columns=['churn'])

        :return: model output (inference results), as a pandas dataframe
        """
        raise ValueError("Please implement predict method")

    def initialize_model(self):
        """
        Invoked when a model is loaded at serving time. Called once per model instance initialization. Can be used for
        loading and storing values that should only be available in a serving setting or loading pretrained models. Optional method

        Example usage:

        >>> def initialize_model(self):
        >>>     with open('model.pkl', 'rb') as infile:
        >>>         self.model = pickle.load(infile)
        """
        pass

    def schema(self) -> ModelSchema:
        """
        Specification of the model inputs and outputs. Optional method

        Example usage:

        >>> from qwak.model.schema import ModelSchema, ExplicitFeature, InferenceOutput
        >>>
        >>>
        >>> def schema(self) -> ModelSchema:
        >>>     model_schema = ModelSchema(
        >>>     features=[
        >>>         ExplicitFeature(name="State", type=str),
        >>>     ],
        >>>     predictions=[
        >>>         InferenceOutput(name="score", type=float)
        >>>     ])
        >>>     return model_schema

        :return: a model schema specification
        """
        pass

    def _add_mixin(self, mixin):
        """
        Adds a mixin to the model. This is used to add functionality to the model without modifying the model itself.
        For Qwak internal use only. Anything added here might be overwritten during the build process.
        :param mixin: The mixin to add to the model
        :return: None
        """
        self.__class__ = type(self.__class__.__name__, (mixin, self.__class__), {})



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/vectors/v1/collection/collection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/vectors/v1/collection/collection.proto\x12\x1fqwak.vector.store.v1.collection\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa2\x01\n\x0cQwakMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x34\n\x10last_modified_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x04 \x01(\t\"?\n\x1aVectorCollectionVectorizer\x12\x19\n\x0fqwak_model_name\x18\x01 \x01(\tH\x00\x42\x06\n\x04type\"\x85\x02\n\x14VectorCollectionSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12O\n\nvectorizer\x18\x03 \x01(\x0b\x32;.qwak.vector.store.v1.collection.VectorCollectionVectorizer\x12G\n\x06metric\x18\x04 \x01(\x0e\x32\x37.qwak.vector.store.v1.collection.VectorCollectionMetric\x12\x11\n\tdimension\x18\x05 \x01(\x05\x12\x1d\n\x15multi_tenancy_enabled\x18\x06 \x01(\x08\"x\n\x1aVectorCollectionDefinition\x12\n\n\x02id\x18\x01 \x01(\t\x12N\n\x0f\x63ollection_spec\x18\x02 \x01(\x0b\x32\x35.qwak.vector.store.v1.collection.VectorCollectionSpec\"\xed\x01\n\x10VectorCollection\x12?\n\x08metadata\x18\x01 \x01(\x0b\x32-.qwak.vector.store.v1.collection.QwakMetadata\x12O\n\ndefinition\x18\x02 \x01(\x0b\x32;.qwak.vector.store.v1.collection.VectorCollectionDefinition\x12G\n\x06status\x18\x03 \x01(\x0e\x32\x37.qwak.vector.store.v1.collection.VectorCollectionStatus\"Z\n\x08Property\x12\x0c\n\x04name\x18\x01 \x01(\t\x12@\n\tdata_type\x18\x02 \x01(\x0e\x32-.qwak.vector.store.v1.collection.PropertyType\"h\n\x12\x43ollectionMetadata\x12\x13\n\x0bnum_vectors\x18\x01 \x01(\x03\x12=\n\nproperties\x18\x02 \x03(\x0b\x32).qwak.vector.store.v1.collection.Property*\x8f\x02\n\x16VectorCollectionStatus\x12\x1d\n\x19\x43OLLECTION_STATUS_INVALID\x10\x00\x12&\n\"COLLECTION_STATUS_CREATE_REQUESTED\x10\x01\x12\x1d\n\x19\x43OLLECTION_STATUS_CREATED\x10\x02\x12#\n\x1f\x43OLLECTION_STATUS_CREATE_FAILED\x10\x03\x12&\n\"COLLECTION_STATUS_DELETE_REQUESTED\x10\x04\x12#\n\x1f\x43OLLECTION_STATUS_DELETE_FAILED\x10\x05\x12\x1d\n\x19\x43OLLECTION_STATUS_DELETED\x10\x06*\xd3\x01\n\x16VectorCollectionMetric\x12\x1d\n\x19\x43OLLECTION_METRIC_INVALID\x10\x00\x12 \n\x1c\x43OLLECTION_METRIC_L2_SQUARED\x10\x01\x12\x1c\n\x18\x43OLLECTION_METRIC_COSINE\x10\x02\x12!\n\x1d\x43OLLECTION_METRIC_DOT_PRODUCT\x10\x03\x12\x18\n\x14\x43OLLECTION_METRIC_L1\x10\x04\x12\x1d\n\x19\x43OLLECTION_METRIC_HAMMING\x10\x05*\xac\x01\n\x0cPropertyType\x12\x19\n\x15PROPERTY_TYPE_INVALID\x10\x00\x12\x18\n\x14PROPERTY_TYPE_STRING\x10\x01\x12\x15\n\x11PROPERTY_TYPE_INT\x10\x02\x12\x18\n\x14PROPERTY_TYPE_DOUBLE\x10\x03\x12\x19\n\x15PROPERTY_TYPE_BOOLEAN\x10\x04\x12\x1b\n\x17PROPERTY_TYPE_TIMESTAMP\x10\x05\x42K\n!com.qwak.ai.vectors.v1.collectionP\x01Z$qwak/vector_management/v1;collectionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.vectors.v1.collection.collection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.qwak.ai.vectors.v1.collectionP\001Z$qwak/vector_management/v1;collection'
  _globals['_VECTORCOLLECTIONSTATUS']._serialized_start=1168
  _globals['_VECTORCOLLECTIONSTATUS']._serialized_end=1439
  _globals['_VECTORCOLLECTIONMETRIC']._serialized_start=1442
  _globals['_VECTORCOLLECTIONMETRIC']._serialized_end=1653
  _globals['_PROPERTYTYPE']._serialized_start=1656
  _globals['_PROPERTYTYPE']._serialized_end=1828
  _globals['_QWAKMETADATA']._serialized_start=114
  _globals['_QWAKMETADATA']._serialized_end=276
  _globals['_VECTORCOLLECTIONVECTORIZER']._serialized_start=278
  _globals['_VECTORCOLLECTIONVECTORIZER']._serialized_end=341
  _globals['_VECTORCOLLECTIONSPEC']._serialized_start=344
  _globals['_VECTORCOLLECTIONSPEC']._serialized_end=605
  _globals['_VECTORCOLLECTIONDEFINITION']._serialized_start=607
  _globals['_VECTORCOLLECTIONDEFINITION']._serialized_end=727
  _globals['_VECTORCOLLECTION']._serialized_start=730
  _globals['_VECTORCOLLECTION']._serialized_end=967
  _globals['_PROPERTY']._serialized_start=969
  _globals['_PROPERTY']._serialized_end=1059
  _globals['_COLLECTIONMETADATA']._serialized_start=1061
  _globals['_COLLECTIONMETADATA']._serialized_end=1165
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/auto_scaling/v1/auto_scaling_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.auto_scaling.v1 import auto_scaling_pb2 as qwak_dot_auto__scaling_dot_v1_dot_auto__scaling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/qwak/auto_scaling/v1/auto_scaling_service.proto\x12\x14qwak.auto_scaling.v1\x1a\'qwak/auto_scaling/v1/auto_scaling.proto\"\x8a\x01\n\x18\x41ttachAutoScalingRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x16\n\x0evariation_name\x18\x02 \x01(\t\x12\x44\n\x13\x61uto_scaling_config\x18\x03 \x01(\x0b\x32\'.qwak.auto_scaling.v1.AutoScalingConfig\"4\n\x19\x41ttachAutoScalingResponse\x12\x17\n\x0f\x61uto_scaling_id\x18\x01 \x01(\t2\x8a\x01\n\x12\x41utoScalingService\x12t\n\x11\x41ttachAutoScaling\x12..qwak.auto_scaling.v1.AttachAutoScalingRequest\x1a/.qwak.auto_scaling.v1.AttachAutoScalingResponseBK\n%com.qwak.ai.management.deployment.apiP\x01Z qwak/auto_scaling/v1;autoscalingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.auto_scaling.v1.auto_scaling_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.management.deployment.apiP\001Z qwak/auto_scaling/v1;autoscaling'
  _globals['_ATTACHAUTOSCALINGREQUEST']._serialized_start=115
  _globals['_ATTACHAUTOSCALINGREQUEST']._serialized_end=253
  _globals['_ATTACHAUTOSCALINGRESPONSE']._serialized_start=255
  _globals['_ATTACHAUTOSCALINGRESPONSE']._serialized_end=307
  _globals['_AUTOSCALINGSERVICE']._serialized_start=310
  _globals['_AUTOSCALINGSERVICE']._serialized_end=448
# @@protoc_insertion_point(module_scope)



from typing import Optional

from _qwak_proto.qwak.feature_store.sources.batch_pb2 import (
    AnonymousS3Configuration as ProtoAnonymousS3Configuration,
    AwsS3AssumeRole as ProtoAwsS3AssumeRole,
    AwsS3FileSystemConfiguration as ProtoAwsS3FileSystemConfiguration,
    GcsServiceAccountImpersonation as ProtoGcsServiceAccountImpersonation,
    GcsUnauthenticated as ProtoGcsUnauthenticated,
)
from qwak.exceptions import QwakException
from qwak.feature_store.data_sources.batch.filesystem.aws import (
    AnonymousS3Configuration,
    AwsS3AssumeRoleFileSystemConfiguration,
    AwsS3FileSystemConfiguration,
)
from qwak.feature_store.data_sources.batch.filesystem.base_config import (
    FileSystemConfiguration,
)
from qwak.feature_store.data_sources.batch.filesystem.gcp import (
    GcpGcsServiceAccountImpersonation,
    GcpGcsUnauthenticated,
)


def get_fs_config_from_proto(filesystem_conf) -> Optional[FileSystemConfiguration]:
    if not filesystem_conf:
        return None

    fs_conf_type = filesystem_conf.WhichOneof("type")

    if not fs_conf_type:
        return None

    fs_conf = getattr(filesystem_conf, fs_conf_type)
    if isinstance(fs_conf, ProtoAwsS3FileSystemConfiguration):
        return AwsS3FileSystemConfiguration._from_proto(fs_conf)

    elif isinstance(fs_conf, ProtoAnonymousS3Configuration):
        return AnonymousS3Configuration._from_proto(fs_conf)

    elif isinstance(fs_conf, ProtoAwsS3AssumeRole):
        return AwsS3AssumeRoleFileSystemConfiguration._from_proto(fs_conf)

    elif isinstance(fs_conf, ProtoGcsServiceAccountImpersonation):
        return GcpGcsServiceAccountImpersonation._from_proto(fs_conf)

    elif isinstance(fs_conf, ProtoGcsUnauthenticated):
        return GcpGcsUnauthenticated._from_proto(fs_conf)

    else:
        raise QwakException(f"Unsupported FileSystemConfiguration: {fs_conf_type}")



from qwak.feature_store.feature_sets.transformations.functions.qwak_pandas import (
    qwak_pandas_udf,
)
from qwak.feature_store.feature_sets.transformations.functions.schema import (
    Column,
    Schema,
    Type,
)

__all__ = ["qwak_pandas_udf", "Column", "Schema", "Type"]



from qwak.inner.const import QwakConstants
from qwak.inner.singleton_meta import SingletonMeta


class Session(metaclass=SingletonMeta):
    __environment = QwakConstants.QWAK_DEFAULT_SECTION

    def set_environment(self, environment):
        self.__environment = environment

    def get_environment(self):
        return self.__environment

    @classmethod
    def clear(cls):
        if cls in cls._instances:
            del cls._instances[cls]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/jobs/v1/job.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$qwak/feature_store/jobs/v1/job.proto\x12\x1aqwak.feature.store.jobs.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc9\x03\n\tJobRecord\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x0e\n\x06run_id\x18\x02 \x01(\x03\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x03 \x01(\t\x12\x15\n\rfeatureset_id\x18\x04 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x05 \x01(\t\x12\x12\n\ntry_number\x18\x06 \x01(\x05\x12\x37\n\tjob_state\x18\x07 \x01(\x0e\x32$.qwak.feature.store.jobs.v1.JobState\x12\x31\n\rcreation_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstart_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x45\n\x10ingestion_window\x18\x0b \x01(\x0b\x32+.qwak.feature.store.jobs.v1.IngestionWindow\x12\x14\n\x0c\x65xecution_id\x18\x0c \x01(\x03\x12\x19\n\x11ingestion_message\x18\r \x01(\t\"\xed\x01\n\x0fIngestionWindow\x12<\n\x18ingested_data_start_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16ingested_data_end_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\"\n\x1aingested_data_updated_rows\x18\x03 \x01(\x05\x12<\n\x18scheduled_execution_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"T\n\x1a\x46\x65\x61turesetLevelJobsSummary\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x1f\n\x17total_num_affected_rows\x18\x02 \x01(\x03*[\n\x08JobState\x12\x0b\n\x07INVALID\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\r\n\tCOMPLETED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\r\n\tTOO_EARLY\x10\x05\x42=\n%com.qwak.ai.feature.store.jobs.v1.apiP\x01Z\x12qwak/fsjobs;fsjobsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.jobs.v1.job_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.feature.store.jobs.v1.apiP\001Z\022qwak/fsjobs;fsjobs'
  _globals['_JOBSTATE']._serialized_start=887
  _globals['_JOBSTATE']._serialized_end=978
  _globals['_JOBRECORD']._serialized_start=102
  _globals['_JOBRECORD']._serialized_end=559
  _globals['_INGESTIONWINDOW']._serialized_start=562
  _globals['_INGESTIONWINDOW']._serialized_end=799
  _globals['_FEATURESETLEVELJOBSSUMMARY']._serialized_start=801
  _globals['_FEATURESETLEVELJOBSSUMMARY']._serialized_end=885
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/container_registry_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0.creds import secret_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_creds_dot_secret__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLqwak/administration/runtime_configuration/v0/container_registry_config.proto\x12\x46qwak.administration.runtime_configuration.v0.container_registry_config\x1a?qwak/administration/runtime_configuration/v0/creds/secret.proto\"\x97\x01\n\x1e\x43ontainerRegistryConfiguration\x12u\n\x04\x61uth\x18\x01 \x01(\x0b\x32g.qwak.administration.runtime_configuration.v0.container_registry_config.ContainerRegistryAuthentication\"\xa4\x01\n\x1f\x43ontainerRegistryAuthentication\x12t\n\x11image_pull_secret\x18\x01 \x01(\x0b\x32W.qwak.administration.runtime_configuration.v0.container_registry_config.ImagePullSecretH\x00\x42\x0b\n\tauth_type\"j\n\x0fImagePullSecret\x12W\n\x06secret\x18\x01 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.creds.secret.SecretKeyRefB\xe6\x01\n?com.jfrog.ml.runtime_configuration.v0.container_registry_configP\x01Z\xa0\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.runtime_configuration.v0.container_registry_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n?com.jfrog.ml.runtime_configuration.v0.container_registry_configP\001Z\240\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0'
  _globals['_CONTAINERREGISTRYCONFIGURATION']._serialized_start=218
  _globals['_CONTAINERREGISTRYCONFIGURATION']._serialized_end=369
  _globals['_CONTAINERREGISTRYAUTHENTICATION']._serialized_start=372
  _globals['_CONTAINERREGISTRYAUTHENTICATION']._serialized_end=536
  _globals['_IMAGEPULLSECRET']._serialized_start=538
  _globals['_IMAGEPULLSECRET']._serialized_end=644
# @@protoc_insertion_point(module_scope)



from pathlib import Path

from qwak.inner.build_logic.interface.build_logger_interface import BuildLogger


def load_patterns_from_ignore_file(build_logger: BuildLogger, ignore_file_path: Path):
    if Path(ignore_file_path).is_file():
        build_logger.info("Found a Qwak ignore file - will ignore listed patterns")

        with open(ignore_file_path, "r") as igonre_file:
            patterns_to_ignore = [
                pattern.strip() for pattern in igonre_file.readlines()
            ]
            build_logger.debug(
                f"Patterns from Qwak igonre file detected - {str(patterns_to_ignore)}"
            )
            return patterns_to_ignore

    build_logger.debug("no Qwak ignore file was found, skipping")
    return []



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.feature_store.jobs.job_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ApplyJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_RECORD_FIELD_NUMBER: builtins.int
    LOGS_PATH_FIELD_NUMBER: builtins.int
    PARTNER_ID_FIELD_NUMBER: builtins.int
    ERROR_TECHNICAL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def job_record(self) -> qwak.feature_store.jobs.job_pb2.JobRecord:
        """The job record to register"""
    logs_path: builtins.str
    """The path of the jobs logs"""
    partner_id: builtins.str
    """The jobs' partner id"""
    error_technical_details: builtins.str
    """Error technical details"""
    def __init__(
        self,
        *,
        job_record: qwak.feature_store.jobs.job_pb2.JobRecord | None = ...,
        logs_path: builtins.str = ...,
        partner_id: builtins.str = ...,
        error_technical_details: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["job_record", b"job_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["error_technical_details", b"error_technical_details", "job_record", b"job_record", "logs_path", b"logs_path", "partner_id", b"partner_id"]) -> None: ...

global___ApplyJobRequest = ApplyJobRequest

class ApplyJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_RUNNING_ID_FIELD_NUMBER: builtins.int
    job_running_id: builtins.int
    def __init__(
        self,
        *,
        job_running_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_running_id", b"job_running_id"]) -> None: ...

global___ApplyJobResponse = ApplyJobResponse

class InitPaginationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """The feature set name of the requested job records"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_name", b"feature_set_name"]) -> None: ...

global___InitPaginationRequest = InitPaginationRequest

class InitPaginationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORD_COUNT_FIELD_NUMBER: builtins.int
    LAST_ID_FIELD_NUMBER: builtins.int
    record_count: builtins.int
    """The amount of records that exist for this pagination session (current total amount of records for the feature set)"""
    last_id: builtins.int
    """The record to use for the after-id in the ListJobs request (gives the actual latest record running_id + 1)"""
    def __init__(
        self,
        *,
        record_count: builtins.int = ...,
        last_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_id", b"last_id", "record_count", b"record_count"]) -> None: ...

global___InitPaginationResponse = InitPaginationResponse

class ListJobsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_NUMBER_FIELD_NUMBER: builtins.int
    AFTER_ID_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """The feature set name of the requested job records"""
    page_size: builtins.int
    """The amount of records to send in the result set"""
    page_number: builtins.int
    """The page number to get"""
    after_id: builtins.int
    """The record id from which we retrieve the data, if unset (defaults to 0) we return the first records"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
        page_size: builtins.int = ...,
        page_number: builtins.int = ...,
        after_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["after_id", b"after_id", "feature_set_name", b"feature_set_name", "page_number", b"page_number", "page_size", b"page_size"]) -> None: ...

global___ListJobsRequest = ListJobsRequest

class ListJobsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBS_FIELD_NUMBER: builtins.int
    @property
    def jobs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.jobs.job_pb2.ElaborateJobRecord]:
        """Result set of the requested jobs"""
    def __init__(
        self,
        *,
        jobs: collections.abc.Iterable[qwak.feature_store.jobs.job_pb2.ElaborateJobRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jobs", b"jobs"]) -> None: ...

global___ListJobsResponse = ListJobsResponse

class GetJobLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """The job id of which the logs are requested"""
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_id", b"job_id"]) -> None: ...

global___GetJobLogsRequest = GetJobLogsRequest

class GetJobLogsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGS_FOLDER_PATH_FIELD_NUMBER: builtins.int
    logs_folder_path: builtins.str
    """The S3 path of the logs folder"""
    def __init__(
        self,
        *,
        logs_folder_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["logs_folder_path", b"logs_folder_path"]) -> None: ...

global___GetJobLogsResponse = GetJobLogsResponse

class GetLatestSuccessfulJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    PARTNER_ID_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """The feature set name of the requested latest successful job record"""
    partner_id: builtins.str
    """The jobs' partner id"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
        partner_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_name", b"feature_set_name", "partner_id", b"partner_id"]) -> None: ...

global___GetLatestSuccessfulJobRequest = GetLatestSuccessfulJobRequest

class GetLatestSuccessfulJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_FIELD_NUMBER: builtins.int
    FOUND_FIELD_NUMBER: builtins.int
    @property
    def job(self) -> qwak.feature_store.jobs.job_pb2.ElaborateJobRecord:
        """the requested job"""
    found: builtins.bool
    """is the job empty or not"""
    def __init__(
        self,
        *,
        job: qwak.feature_store.jobs.job_pb2.ElaborateJobRecord | None = ...,
        found: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["job", b"job"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["found", b"found", "job", b"job"]) -> None: ...

global___GetLatestSuccessfulJobResponse = GetLatestSuccessfulJobResponse

class DeleteFeatureSetJobsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """The feature set name of the requested delete feature set jobs"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_name", b"feature_set_name"]) -> None: ...

global___DeleteFeatureSetJobsRequest = DeleteFeatureSetJobsRequest

class DeleteFeatureSetJobsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETED_JOB_RECORDS_COUNT_FIELD_NUMBER: builtins.int
    deleted_job_records_count: builtins.int
    def __init__(
        self,
        *,
        deleted_job_records_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deleted_job_records_count", b"deleted_job_records_count"]) -> None: ...

global___DeleteFeatureSetJobsResponse = DeleteFeatureSetJobsResponse



from typing import Optional

from frogml_storage.authentication.models import AuthConfig


def login_input_checks(
    url: Optional[str] = None,
    username: Optional[str] = None,
    password: Optional[str] = None,
    token: Optional[str] = None,
    anonymous: bool = False,
) -> bool:
    return (
        __is_user_name_password_command(url, username, password, token, anonymous)
        or __is_access_token_command(url, username, password, token, anonymous)
        or __is_anonymous_command(url, username, password, token, anonymous)
    )


def is_login_without_params(
    url: Optional[str] = None,
    username: Optional[str] = None,
    password: Optional[str] = None,
    token: Optional[str] = None,
    anonymous: bool = False,
) -> bool:
    return (
        all(params is None for params in [url, username, password, token])
        and not anonymous
    )


def is_username_password_login(
    auth_config: AuthConfig, anonymous: Optional[bool] = False
) -> bool:
    return __is_user_name_password_command(
        url=auth_config.artifactory_url,
        username=auth_config.user,
        password=auth_config.password,
        token=auth_config.access_token,
        anonymous=anonymous,
    )


def is_access_token_login(
    auth_config: AuthConfig, anonymous: Optional[bool] = False
) -> bool:
    if anonymous is None:
        anonymous = False
    return __is_access_token_command(
        url=auth_config.artifactory_url,
        username=auth_config.user,
        password=auth_config.password,
        token=auth_config.access_token,
        anonymous=anonymous,
    )


def is_anonymous_login(
    auth_config: AuthConfig, anonymous: Optional[bool] = False
) -> bool:
    if anonymous is None:
        anonymous = False
    return __is_anonymous_command(
        url=auth_config.artifactory_url,
        username=auth_config.user,
        password=auth_config.password,
        token=auth_config.access_token,
        anonymous=anonymous,
    )


def __is_anonymous_command(
    url: Optional[str],
    username: Optional[str],
    password: Optional[str],
    token: Optional[str],
    anonymous: bool,
) -> bool:
    return (
        anonymous
        and all(params is None for params in [username, password, token])
        and url is not None
    )


def __is_access_token_command(
    url: Optional[str],
    username: Optional[str],
    password: Optional[str],
    token: Optional[str],
    anonymous: bool,
) -> bool:
    if anonymous:
        return False
    return all(params is None for params in [username, password]) and all(
        params is not None for params in [url, token]
    )


def __is_user_name_password_command(
    url: Optional[str],
    username: Optional[str],
    password: Optional[str],
    token: Optional[str],
    anonymous: Optional[bool] = False,
) -> bool:
    return (
        not anonymous
        and url is not None
        and username is not None
        and password is not None
        and token is None
    )



from typing import Any

from .base_output_adapter import BaseOutputAdapter


class DataFrameOutputAdapter(BaseOutputAdapter):
    def __init__(self, output_orient: str = "records"):
        self.output_orient = output_orient

    @staticmethod
    def pack_user_func_return_value(return_result: Any) -> str:
        pass



import dataclasses
from typing import Dict, List, cast

from qwak.exceptions import QwakException
from qwak.feature_store._common.feature_set_utils import (
    FeatureSetInfo,
    get_entity_type,
    get_typed_feature,
)
from qwak.model.fs_info_mapping_retriever import retrieve_fs_mapping
from qwak.model.schema_entities import BaseFeature, Entity, FeatureStoreInput
from qwak.model.utils.feature_utils import (
    discard_env_from_name,
    extract_env_name,
    extract_featureset_name,
    validate_and_sanitize_features_name,
)


def normalize_features(
    features: List[BaseFeature],
    env_to_feature_sets_infos: Dict[str, Dict[str, FeatureSetInfo]],
) -> List[BaseFeature]:
    """
    Adding the relevant entity to the feature set features
    Args:
        features: list of features
        env_to_feature_sets_infos: dict of environment name to feature set name to it's entity
    return normalize features - the features with the entities
    :param
    """
    new_normalize_features = []
    for feature in features:
        if isinstance(feature, FeatureStoreInput):
            feature_set_env = extract_env_name(feature.name)
            feature_set_name = extract_featureset_name(feature.name)
            feature_set_to_feature_set_info = env_to_feature_sets_infos.get(
                feature_set_env
            )
            if feature_set_to_feature_set_info is None:
                raise QwakException(f"Environment '{feature_set_env}' does not exist")
            feature_set_info = feature_set_to_feature_set_info.get(feature_set_name)
            if feature_set_info is None:
                raise QwakException(
                    f"Featureset '{feature_set_name}' does not exist in env '{feature_set_env}'"  # noqa
                )
            entity_spec = feature_set_info.entity_spec
            retrieved_entity = Entity(
                name=entity_spec.keys[
                    0
                ],  # currently support only one entity key per feature set
                type=get_entity_type(entity_spec.value_type),
            )
            if (
                feature.entity
                and retrieved_entity.name.lower() != feature.entity.name.lower()
            ):
                raise QwakException(
                    f"Explicitly supplied with an invalid entity: {feature.entity}, "
                    f"actual: {retrieved_entity}"
                )
            feature.entity = retrieved_entity
            feature.entity.name = feature.entity.name.lower()
            feature_type = feature_set_info.feature_set_type
            feature_version = feature_set_info.feature_version
            feature_without_env = cast(
                FeatureStoreInput,
                dataclasses.replace(feature, name=discard_env_from_name(feature.name)),
            )
            feature = get_typed_feature(
                feature_without_env, feature_type, feature_version
            )
        new_normalize_features.append(feature)
    return new_normalize_features


def adding_entities_to_schema(entities: List[Entity], features: List[BaseFeature]):
    """
    Adding the new entities for feature store feature to the entities list from schema
    Args:
        entities: list of entities
        features: list of features
    Returns: the entities with the new entities from the feature store features
    """
    entity_name_to_entity = {entity.name: entity for entity in entities}
    for feature in features:
        if isinstance(feature, FeatureStoreInput):
            entity_name_to_entity[feature.entity.name] = feature.entity

    for entity in entity_name_to_entity.values():
        entity.name = entity.name.lower()

    return list(set(entity_name_to_entity.values()))


def normalize_schema(features: List[BaseFeature], entities: List[Entity]):
    """
    validate and sanitize the feature names and entities
    Normalize schema - will add entity to each features in schema if not exists
    Arg:
        model: the model with the required schema
    Return:
        updated model
    """
    sanitized_features = validate_and_sanitize_features_name(features)
    fs_info_cache = retrieve_fs_mapping(sanitized_features)

    normalized_features = normalize_features(sanitized_features, fs_info_cache)
    normalized_entities = adding_entities_to_schema(entities, sanitized_features)

    return normalized_features, normalized_entities


def enrich_schema(features: List[BaseFeature], entities: List[Entity]):
    normalized_features, normalized_entities = normalize_schema(features, entities)
    return normalized_features, normalized_entities



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import qwak.user_application.common.v0.resources_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PurchaseOption:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PurchaseOptionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PurchaseOption.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID_PURCHASE_OPTION: _PurchaseOption.ValueType  # 0
    SPOT_PURCHASE_OPTION: _PurchaseOption.ValueType  # 1
    ONDEMAND_PURCHASE_OPTION: _PurchaseOption.ValueType  # 2

class PurchaseOption(_PurchaseOption, metaclass=_PurchaseOptionEnumTypeWrapper): ...

INVALID_PURCHASE_OPTION: PurchaseOption.ValueType  # 0
SPOT_PURCHASE_OPTION: PurchaseOption.ValueType  # 1
ONDEMAND_PURCHASE_OPTION: PurchaseOption.ValueType  # 2
global___PurchaseOption = PurchaseOption

class _CloudProvider:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CloudProviderEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CloudProvider.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID_CLOUD_PROVIDER: _CloudProvider.ValueType  # 0
    AWS: _CloudProvider.ValueType  # 1
    GCP: _CloudProvider.ValueType  # 2
    AZURE: _CloudProvider.ValueType  # 3

class CloudProvider(_CloudProvider, metaclass=_CloudProviderEnumTypeWrapper): ...

INVALID_CLOUD_PROVIDER: CloudProvider.ValueType  # 0
AWS: CloudProvider.ValueType  # 1
GCP: CloudProvider.ValueType  # 2
AZURE: CloudProvider.ValueType  # 3
global___CloudProvider = CloudProvider

class _MemoryUnit:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MemoryUnitEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MemoryUnit.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID_MEMORY_UNIT: _MemoryUnit.ValueType  # 0
    MIB: _MemoryUnit.ValueType  # 1
    GIB: _MemoryUnit.ValueType  # 2

class MemoryUnit(_MemoryUnit, metaclass=_MemoryUnitEnumTypeWrapper): ...

INVALID_MEMORY_UNIT: MemoryUnit.ValueType  # 0
MIB: MemoryUnit.ValueType  # 1
GIB: MemoryUnit.ValueType  # 2
global___MemoryUnit = MemoryUnit

class _LogsVerbosityLevel:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LogsVerbosityLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LogsVerbosityLevel.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID_LOGS_VERBOSITY: _LogsVerbosityLevel.ValueType  # 0
    DEBUG: _LogsVerbosityLevel.ValueType  # 10
    INFO: _LogsVerbosityLevel.ValueType  # 20
    CRITICAL: _LogsVerbosityLevel.ValueType  # 50

class LogsVerbosityLevel(_LogsVerbosityLevel, metaclass=_LogsVerbosityLevelEnumTypeWrapper): ...

INVALID_LOGS_VERBOSITY: LogsVerbosityLevel.ValueType  # 0
DEBUG: LogsVerbosityLevel.ValueType  # 10
INFO: LogsVerbosityLevel.ValueType  # 20
CRITICAL: LogsVerbosityLevel.ValueType  # 50
global___LogsVerbosityLevel = LogsVerbosityLevel

class ModelBuildValues(google.protobuf.message.Message):
    """Represents all values required for initiating a model build job.
    Mirrors the Helm chart values used by Admiral to deploy model builds.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_INFO_FIELD_NUMBER: builtins.int
    MODEL_METADATA_FIELD_NUMBER: builtins.int
    MODEL_CODE_LOCATION_FIELD_NUMBER: builtins.int
    BUILD_EXECUTION_SPEC_FIELD_NUMBER: builtins.int
    SDK_SPEC_FIELD_NUMBER: builtins.int
    JFROG_ECOSYSTEM_SPEC_FIELD_NUMBER: builtins.int
    JOB_SPEC_FIELD_NUMBER: builtins.int
    @property
    def build_info(self) -> global___BuildInfo:
        """Build identifiers, tags, parameters, and serialized configuration."""
    @property
    def model_metadata(self) -> global___ModelMetadata:
        """Identifiers and ownership metadata."""
    @property
    def model_code_location(self) -> global___ModelCodeLocation:
        """Location of model code"""
    @property
    def build_execution_spec(self) -> global___BuildExecutionSpec:
        """Execution parameters for the build process."""
    @property
    def sdk_spec(self) -> global___SdkSpec:
        """Environment and SDK-specific execution config."""
    @property
    def jfrog_ecosystem_spec(self) -> global___JfrogEcosystemSpec:
        """Access settings for JFrog ecosystem."""
    @property
    def job_spec(self) -> global___JobSpec:
        """Infrastructure and runtime settings for the build job."""
    def __init__(
        self,
        *,
        build_info: global___BuildInfo | None = ...,
        model_metadata: global___ModelMetadata | None = ...,
        model_code_location: global___ModelCodeLocation | None = ...,
        build_execution_spec: global___BuildExecutionSpec | None = ...,
        sdk_spec: global___SdkSpec | None = ...,
        jfrog_ecosystem_spec: global___JfrogEcosystemSpec | None = ...,
        job_spec: global___JobSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_execution_spec", b"build_execution_spec", "build_info", b"build_info", "jfrog_ecosystem_spec", b"jfrog_ecosystem_spec", "job_spec", b"job_spec", "model_code_location", b"model_code_location", "model_metadata", b"model_metadata", "sdk_spec", b"sdk_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_execution_spec", b"build_execution_spec", "build_info", b"build_info", "jfrog_ecosystem_spec", b"jfrog_ecosystem_spec", "job_spec", b"job_spec", "model_code_location", b"model_code_location", "model_metadata", b"model_metadata", "sdk_spec", b"sdk_spec"]) -> None: ...

global___ModelBuildValues = ModelBuildValues

class BuildInfo(google.protobuf.message.Message):
    """Build identifiers, tags, parameters, and serialized configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    BRANCH_NAME_FIELD_NUMBER: builtins.int
    BUILD_TAGS_FIELD_NUMBER: builtins.int
    BUILD_CONFIG_FIELD_NUMBER: builtins.int
    BUILD_PROPERTIES_V1_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    branch_name: builtins.str
    @property
    def build_tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    build_config: builtins.str
    """Serialized build configuration."""
    @property
    def build_properties_v1(self) -> global___BuildPropertiesV1: ...
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
        branch_name: builtins.str = ...,
        build_tags: collections.abc.Iterable[builtins.str] | None = ...,
        build_config: builtins.str = ...,
        build_properties_v1: global___BuildPropertiesV1 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_properties_v1", b"build_properties_v1"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_name", b"branch_name", "build_config", b"build_config", "build_id", b"build_id", "build_properties_v1", b"build_properties_v1", "build_tags", b"build_tags"]) -> None: ...

global___BuildInfo = BuildInfo

class BuildPropertiesV1(google.protobuf.message.Message):
    """Build artifact urls set at upload time"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_CONFIG_URL_FIELD_NUMBER: builtins.int
    SDK_WHEEL_URL_FIELD_NUMBER: builtins.int
    SDK_VERSION_URL_FIELD_NUMBER: builtins.int
    build_config_url: builtins.str
    sdk_wheel_url: builtins.str
    sdk_version_url: builtins.str
    def __init__(
        self,
        *,
        build_config_url: builtins.str = ...,
        sdk_wheel_url: builtins.str = ...,
        sdk_version_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_config_url", b"build_config_url", "sdk_version_url", b"sdk_version_url", "sdk_wheel_url", b"sdk_wheel_url"]) -> None: ...

global___BuildPropertiesV1 = BuildPropertiesV1

class ModelMetadata(google.protobuf.message.Message):
    """Metadata identifying the model and its ownership."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    ARTIFACTORY_DETAILS_FIELD_NUMBER: builtins.int
    MODEL_GROUP_NAME_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    account_id: builtins.str
    user_id: builtins.str
    @property
    def artifactory_details(self) -> global___ArtifactoryDetails: ...
    model_group_name: builtins.str
    """Human readable model group identifier (e.g., "my-model-group").
    This is the display name, not the UUID.
    """
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        account_id: builtins.str = ...,
        user_id: builtins.str = ...,
        artifactory_details: global___ArtifactoryDetails | None = ...,
        model_group_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["artifactory_details", b"artifactory_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "artifactory_details", b"artifactory_details", "model_group_name", b"model_group_name", "model_id", b"model_id", "user_id", b"user_id"]) -> None: ...

global___ModelMetadata = ModelMetadata

class ArtifactoryDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_KEY_FIELD_NUMBER: builtins.int
    project_key: builtins.str
    def __init__(
        self,
        *,
        project_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["project_key", b"project_key"]) -> None: ...

global___ArtifactoryDetails = ArtifactoryDetails

class ModelCodeLocation(google.protobuf.message.Message):
    """References to the model's storage location and source control info."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAIN_MODEL_DIRECTORY_FIELD_NUMBER: builtins.int
    LOCAL_URI_FIELD_NUMBER: builtins.int
    GIT_URI_FIELD_NUMBER: builtins.int
    main_model_directory: builtins.str
    @property
    def local_uri(self) -> global___LocalUri: ...
    @property
    def git_uri(self) -> global___GitUri: ...
    def __init__(
        self,
        *,
        main_model_directory: builtins.str = ...,
        local_uri: global___LocalUri | None = ...,
        git_uri: global___GitUri | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["git_uri", b"git_uri", "local_uri", b"local_uri", "uri", b"uri"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["git_uri", b"git_uri", "local_uri", b"local_uri", "main_model_directory", b"main_model_directory", "uri", b"uri"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["uri", b"uri"]) -> typing_extensions.Literal["local_uri", "git_uri"] | None: ...

global___ModelCodeLocation = ModelCodeLocation

class LocalUri(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path"]) -> None: ...

global___LocalUri = LocalUri

class GitUri(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    GIT_DETAILS_FIELD_NUMBER: builtins.int
    url: builtins.str
    @property
    def git_details(self) -> global___GitDetails: ...
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        git_details: global___GitDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["git_details", b"git_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["git_details", b"git_details", "url", b"url"]) -> None: ...

global___GitUri = GitUri

class GitDetails(google.protobuf.message.Message):
    """Git source control information used for the build."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BRANCH_FIELD_NUMBER: builtins.int
    COMMIT_ID_FIELD_NUMBER: builtins.int
    CREDENTIALS_FIELD_NUMBER: builtins.int
    CREDENTIALS_SECRET_NAME_FIELD_NUMBER: builtins.int
    branch: builtins.str
    commit_id: builtins.str
    credentials: builtins.str
    credentials_secret_name: builtins.str
    def __init__(
        self,
        *,
        branch: builtins.str = ...,
        commit_id: builtins.str = ...,
        credentials: builtins.str = ...,
        credentials_secret_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "credentials_secret_name", b"credentials_secret_name", "git_credentials", b"git_credentials"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch", b"branch", "commit_id", b"commit_id", "credentials", b"credentials", "credentials_secret_name", b"credentials_secret_name", "git_credentials", b"git_credentials"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["git_credentials", b"git_credentials"]) -> typing_extensions.Literal["credentials", "credentials_secret_name"] | None: ...

global___GitDetails = GitDetails

class BuildExecutionSpec(google.protobuf.message.Message):
    """Specifies how the build should be executed."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_IMAGE_DESTINATION_FIELD_NUMBER: builtins.int
    SHOULD_BUILD_WITHOUT_CACHE_FIELD_NUMBER: builtins.int
    LOGS_VERBOSITY_LEVEL_FIELD_NUMBER: builtins.int
    BASE_IMAGE_FIELD_NUMBER: builtins.int
    CUSTOM_IAM_ROLE_ARN_FIELD_NUMBER: builtins.int
    ENV_VARS_FIELD_NUMBER: builtins.int
    REMOTE_BUILDER_AUTH_SECRET_NAME_FIELD_NUMBER: builtins.int
    CONTAINER_ENGINE_FIELD_NUMBER: builtins.int
    build_image_destination: builtins.str
    """Destination image to be built and pushed."""
    should_build_without_cache: builtins.bool
    """If true, disables build caching."""
    logs_verbosity_level: global___LogsVerbosityLevel.ValueType
    """Verbosity level for build logs."""
    base_image: builtins.str
    """Base Docker image used in the build."""
    custom_iam_role_arn: builtins.str
    """Custom IAM role used during the build."""
    @property
    def env_vars(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Env var parameters used in the build process"""
    remote_builder_auth_secret_name: builtins.str
    """Secret name for the remote builder, used for remote build registry authentication"""
    @property
    def container_engine(self) -> global___ContainerEngine:
        """Container engine to use for the build (e.g., Docker, Podman)"""
    def __init__(
        self,
        *,
        build_image_destination: builtins.str = ...,
        should_build_without_cache: builtins.bool = ...,
        logs_verbosity_level: global___LogsVerbosityLevel.ValueType = ...,
        base_image: builtins.str = ...,
        custom_iam_role_arn: builtins.str = ...,
        env_vars: collections.abc.Iterable[builtins.str] | None = ...,
        remote_builder_auth_secret_name: builtins.str = ...,
        container_engine: global___ContainerEngine | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["container_engine", b"container_engine"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_image", b"base_image", "build_image_destination", b"build_image_destination", "container_engine", b"container_engine", "custom_iam_role_arn", b"custom_iam_role_arn", "env_vars", b"env_vars", "logs_verbosity_level", b"logs_verbosity_level", "remote_builder_auth_secret_name", b"remote_builder_auth_secret_name", "should_build_without_cache", b"should_build_without_cache"]) -> None: ...

global___BuildExecutionSpec = BuildExecutionSpec

class SdkSpec(google.protobuf.message.Message):
    """Specifies the SDK environment and configuration used to execute the build."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SDK_VERSION_FIELD_NUMBER: builtins.int
    SDK_EXTRA_INDEX_URL_FIELD_NUMBER: builtins.int
    SDK_RUNTIME_VERSION_OVERRIDE_FIELD_NUMBER: builtins.int
    sdk_version: builtins.str
    sdk_extra_index_url: builtins.str
    sdk_runtime_version_override: builtins.str
    def __init__(
        self,
        *,
        sdk_version: builtins.str = ...,
        sdk_extra_index_url: builtins.str = ...,
        sdk_runtime_version_override: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sdk_extra_index_url", b"sdk_extra_index_url", "sdk_runtime_version_override", b"sdk_runtime_version_override", "sdk_version", b"sdk_version"]) -> None: ...

global___SdkSpec = SdkSpec

class JfrogEcosystemSpec(google.protobuf.message.Message):
    """JFrog ecosystem configuration, used for authentication and configuration"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASEURL_FIELD_NUMBER: builtins.int
    ACCESSTOKENSECRETNAME_FIELD_NUMBER: builtins.int
    ARTIFACTORYSETTINGSSECRETNAME_FIELD_NUMBER: builtins.int
    baseUrl: builtins.str
    accessTokenSecretName: builtins.str
    artifactorySettingsSecretName: builtins.str
    def __init__(
        self,
        *,
        baseUrl: builtins.str = ...,
        accessTokenSecretName: builtins.str = ...,
        artifactorySettingsSecretName: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["accessTokenSecretName", b"accessTokenSecretName", "artifactorySettingsSecretName", b"artifactorySettingsSecretName", "baseUrl", b"baseUrl"]) -> None: ...

global___JfrogEcosystemSpec = JfrogEcosystemSpec

class JobSpec(google.protobuf.message.Message):
    """Describes the runtime and infrastructure settings for a build job."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class BuildExecutorEnvVarsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAMESPACE_FIELD_NUMBER: builtins.int
    PROVISION_INSTANCE_TIMEOUT_FIELD_NUMBER: builtins.int
    PURCHASE_OPTION_FIELD_NUMBER: builtins.int
    IS_NODE_OPTIMIZATION_ENABLED_FIELD_NUMBER: builtins.int
    SHOULD_USE_BUILD_ISOLATION_FIELD_NUMBER: builtins.int
    IS_MULTI_TENANT_ENVIRONMENT_FIELD_NUMBER: builtins.int
    IS_SELF_HOSTED_JPD_FIELD_NUMBER: builtins.int
    BUILD_EXECUTOR_IMAGE_URL_FIELD_NUMBER: builtins.int
    CLOUD_PROVIDER_FIELD_NUMBER: builtins.int
    JOB_SIZE_FIELD_NUMBER: builtins.int
    BUILD_EXECUTOR_ENV_VARS_FIELD_NUMBER: builtins.int
    namespace: builtins.str
    """Kubernetes namespace in which to run the build job."""
    provision_instance_timeout: builtins.int
    purchase_option: global___PurchaseOption.ValueType
    is_node_optimization_enabled: builtins.bool
    should_use_build_isolation: builtins.bool
    is_multi_tenant_environment: builtins.bool
    is_self_hosted_jpd: builtins.bool
    build_executor_image_url: builtins.str
    """Image used for the build executor."""
    cloud_provider: global___CloudProvider.ValueType
    @property
    def job_size(self) -> global___JobSize: ...
    @property
    def build_executor_env_vars(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Environment variables to set on the build executor container."""
    def __init__(
        self,
        *,
        namespace: builtins.str = ...,
        provision_instance_timeout: builtins.int = ...,
        purchase_option: global___PurchaseOption.ValueType = ...,
        is_node_optimization_enabled: builtins.bool = ...,
        should_use_build_isolation: builtins.bool = ...,
        is_multi_tenant_environment: builtins.bool = ...,
        is_self_hosted_jpd: builtins.bool = ...,
        build_executor_image_url: builtins.str = ...,
        cloud_provider: global___CloudProvider.ValueType = ...,
        job_size: global___JobSize | None = ...,
        build_executor_env_vars: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["job_size", b"job_size"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_executor_env_vars", b"build_executor_env_vars", "build_executor_image_url", b"build_executor_image_url", "cloud_provider", b"cloud_provider", "is_multi_tenant_environment", b"is_multi_tenant_environment", "is_node_optimization_enabled", b"is_node_optimization_enabled", "is_self_hosted_jpd", b"is_self_hosted_jpd", "job_size", b"job_size", "namespace", b"namespace", "provision_instance_timeout", b"provision_instance_timeout", "purchase_option", b"purchase_option", "should_use_build_isolation", b"should_use_build_isolation"]) -> None: ...

global___JobSpec = JobSpec

class JobSize(google.protobuf.message.Message):
    """Defines the CPU, memory, and GPU resources allocated to a build job."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CPU_FIELD_NUMBER: builtins.int
    MEMORY_AMOUNT_FIELD_NUMBER: builtins.int
    MEMORY_UNITS_FIELD_NUMBER: builtins.int
    GPU_RESOURCES_FIELD_NUMBER: builtins.int
    CLIENT_POD_COMPUTE_RESOURCES_FIELD_NUMBER: builtins.int
    cpu: builtins.float
    memory_amount: builtins.int
    memory_units: global___MemoryUnit.ValueType
    @property
    def gpu_resources(self) -> qwak.user_application.common.v0.resources_pb2.GpuResources: ...
    @property
    def client_pod_compute_resources(self) -> qwak.user_application.common.v0.resources_pb2.ClientPodComputeResources: ...
    def __init__(
        self,
        *,
        cpu: builtins.float = ...,
        memory_amount: builtins.int = ...,
        memory_units: global___MemoryUnit.ValueType = ...,
        gpu_resources: qwak.user_application.common.v0.resources_pb2.GpuResources | None = ...,
        client_pod_compute_resources: qwak.user_application.common.v0.resources_pb2.ClientPodComputeResources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["client_pod_compute_resources", b"client_pod_compute_resources", "gpu_resources", b"gpu_resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_pod_compute_resources", b"client_pod_compute_resources", "cpu", b"cpu", "gpu_resources", b"gpu_resources", "memory_amount", b"memory_amount", "memory_units", b"memory_units"]) -> None: ...

global___JobSize = JobSize

class ContainerEngine(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOCKER_FIELD_NUMBER: builtins.int
    PODMAN_FIELD_NUMBER: builtins.int
    @property
    def docker(self) -> global___DockerContainerEngine: ...
    @property
    def podman(self) -> global___PodmanContainerEngine: ...
    def __init__(
        self,
        *,
        docker: global___DockerContainerEngine | None = ...,
        podman: global___PodmanContainerEngine | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["docker", b"docker", "podman", b"podman", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["docker", b"docker", "podman", b"podman", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["docker", "podman"] | None: ...

global___ContainerEngine = ContainerEngine

class DockerContainerEngine(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DockerContainerEngine = DockerContainerEngine

class PodmanContainerEngine(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PodmanContainerEngine = PodmanContainerEngine



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PodStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_STATUSES_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    PHASE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    POD_ID_FIELD_NUMBER: builtins.int
    @property
    def container_statuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerStatus]: ...
    message: builtins.str
    phase: builtins.str
    reason: builtins.str
    start_time: builtins.str
    pod_id: builtins.str
    def __init__(
        self,
        *,
        container_statuses: collections.abc.Iterable[global___ContainerStatus] | None = ...,
        message: builtins.str = ...,
        phase: builtins.str = ...,
        reason: builtins.str = ...,
        start_time: builtins.str = ...,
        pod_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_statuses", b"container_statuses", "message", b"message", "phase", b"phase", "pod_id", b"pod_id", "reason", b"reason", "start_time", b"start_time"]) -> None: ...

global___PodStatus = PodStatus

class ContainerStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    RESTART_COUNT_FIELD_NUMBER: builtins.int
    STARTED_FIELD_NUMBER: builtins.int
    CONTAINER_STATE_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    image: builtins.str
    restart_count: builtins.int
    started: builtins.bool
    @property
    def container_state(self) -> global___ContainerState: ...
    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
        image: builtins.str = ...,
        restart_count: builtins.int = ...,
        started: builtins.bool = ...,
        container_state: global___ContainerState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["container_state", b"container_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_id", b"container_id", "container_state", b"container_state", "image", b"image", "restart_count", b"restart_count", "started", b"started"]) -> None: ...

global___ContainerStatus = ContainerStatus

class ContainerState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_STATE_RUNNING_FIELD_NUMBER: builtins.int
    CONTAINER_STATE_TERMINATED_FIELD_NUMBER: builtins.int
    CONTAINER_STATE_WAITING_FIELD_NUMBER: builtins.int
    @property
    def container_state_running(self) -> global___ContainerStateRunning: ...
    @property
    def container_state_terminated(self) -> global___ContainerStateTerminated: ...
    @property
    def container_state_waiting(self) -> global___ContainerStateWaiting: ...
    def __init__(
        self,
        *,
        container_state_running: global___ContainerStateRunning | None = ...,
        container_state_terminated: global___ContainerStateTerminated | None = ...,
        container_state_waiting: global___ContainerStateWaiting | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["container_state_running", b"container_state_running", "container_state_terminated", b"container_state_terminated", "container_state_waiting", b"container_state_waiting", "state", b"state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_state_running", b"container_state_running", "container_state_terminated", b"container_state_terminated", "container_state_waiting", b"container_state_waiting", "state", b"state"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["state", b"state"]) -> typing_extensions.Literal["container_state_running", "container_state_terminated", "container_state_waiting"] | None: ...

global___ContainerState = ContainerState

class ContainerStateRunning(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STARTED_AT_FIELD_NUMBER: builtins.int
    started_at: builtins.str
    def __init__(
        self,
        *,
        started_at: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["started_at", b"started_at"]) -> None: ...

global___ContainerStateRunning = ContainerStateRunning

class ContainerStateTerminated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    EXIT_CODE_FIELD_NUMBER: builtins.int
    FINISHED_AT_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    SIGNAL_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    exit_code: builtins.int
    finished_at: builtins.str
    message: builtins.str
    reason: builtins.str
    signal: builtins.int
    started_at: builtins.str
    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
        exit_code: builtins.int = ...,
        finished_at: builtins.str = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        signal: builtins.int = ...,
        started_at: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_id", b"container_id", "exit_code", b"exit_code", "finished_at", b"finished_at", "message", b"message", "reason", b"reason", "signal", b"signal", "started_at", b"started_at"]) -> None: ...

global___ContainerStateTerminated = ContainerStateTerminated

class ContainerStateWaiting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    message: builtins.str
    reason: builtins.str
    def __init__(
        self,
        *,
        message: builtins.str = ...,
        reason: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message", "reason", b"reason"]) -> None: ...

global___ContainerStateWaiting = ContainerStateWaiting



from typing import Optional

import grpc
from _qwak_proto.qwak.models.models_pb2 import (
    CreateModelRequest,
    DeleteModelRequest,
    GetModelMetadataRequest,
    ListModelsMetadataRequest,
    ListModelsRequest,
    GetModelRequest,
    Model,
    ModelSpec,
)
from _qwak_proto.qwak.models.models_pb2_grpc import ModelsManagementServiceStub
from _qwak_proto.qwak.projects.jfrog_project_spec_pb2 import ModelRepositoryJFrogSpec
from dependency_injector.wiring import Provide
from qwak.exceptions import QwakException
from qwak.inner.di_configuration import QwakContainer


class ModelsManagementClient:
    """
    Used for interacting with Feature Registry endpoints
    """

    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self._models_management_service = ModelsManagementServiceStub(grpc_channel)

    def get_model(self, model_id, exception_on_missing: bool = True) -> Optional[Model]:
        try:
            return self._models_management_service.GetModel(
                GetModelRequest(model_id=model_id)
            ).model

        except grpc.RpcError as e:
            if e.code() == grpc.StatusCode.NOT_FOUND and not exception_on_missing:
                return None
            raise QwakException(f"Failed to get model, error is {e.details()}")

    def get_model_by_uuid(
        self, model_uuid, exception_on_missing: bool = True
    ) -> Optional[Model]:
        try:
            return self._models_management_service.GetModel(
                GetModelRequest(model_uuid=model_uuid)
            ).model

        except grpc.RpcError as e:
            if e.code() == grpc.StatusCode.NOT_FOUND and not exception_on_missing:
                return None
            raise QwakException(f"Failed to get model, error is {e.details()}")

    def get_model_uuid(self, model_id):
        model = self.get_model(model_id)
        return model.uuid

    def create_model(
        self,
        project_id,
        model_name,
        model_description,
        jfrog_project_key: Optional[str] = None,
    ):
        try:
            return self._models_management_service.CreateModel(
                CreateModelRequest(
                    model_spec=ModelSpec(
                        model_named_id=model_name.lower().replace(" ", "-"),
                        display_name=model_name,
                        project_id=project_id,
                        model_description=model_description,
                    ),
                    jfrog_project_spec=ModelRepositoryJFrogSpec(
                        jfrog_project_key=jfrog_project_key,
                    ),
                )
            )

        except grpc.RpcError as e:
            raise QwakException(f"Failed to create model, error is {e}")

    def delete_model(self, project_id, model_id):
        try:
            return self._models_management_service.DeleteModel(
                DeleteModelRequest(model_id=model_id, project_id=project_id)
            )

        except grpc.RpcError as e:
            raise QwakException(f"Failed to delete model, error is {e.details()}")

    def is_model_exists(self, model_id: str) -> bool:
        """Check if model exists in environment

        Args:
            model_id: the model id to check if exists.

        Returns: if model exists.
        """
        try:
            self._models_management_service.GetModel(
                GetModelRequest(model_id=model_id)
            ).model
            return True
        except grpc.RpcError as e:
            if e.code() == grpc.StatusCode.NOT_FOUND:
                return False
            raise QwakException(
                f"Failed to check if model {model_id} is exists, error is {e.details()}"
            )

    def list_models_metadata(self, project_id: str):
        try:
            return self._models_management_service.ListModelsMetadata(
                ListModelsMetadataRequest(project_id=project_id)
            )
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to list models metadata, error is {e.details()}"
            )

    def list_models(self, project_id: str):
        try:
            return self._models_management_service.ListModels(
                ListModelsRequest(project_id=project_id)
            )
        except grpc.RpcError as e:
            raise QwakException(f"Failed to list models, error is {e.details()}")

    def get_model_metadata(self, model_id: str):
        try:
            return self._models_management_service.GetModelMetadata(
                GetModelMetadataRequest(model_id=model_id)
            )
        except grpc.RpcError as e:
            raise QwakException(f"Failed to get model metadata, error is {e.details()}")



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import qwak.integration.hugging_face_integration_pb2
import qwak.integration.open_a_i_integration_pb2
import qwak.integration.opsgenie_integration_pb2
import qwak.integration.pagerduty_integration_pb2
import qwak.integration.slack_app_integration_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _IntegrationType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _IntegrationTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_IntegrationType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INTEGRATION_TYPE_INVALID: _IntegrationType.ValueType  # 0
    INTEGRATION_TYPE_JFROG: _IntegrationType.ValueType  # 1
    INTEGRATION_TYPE_OPSGENIE: _IntegrationType.ValueType  # 2
    INTEGRATION_TYPE_PAGERDUTY: _IntegrationType.ValueType  # 3
    INTEGRATION_TYPE_QWAK_SLACK_APP: _IntegrationType.ValueType  # 4
    INTEGRATION_TYPE_OPENAI: _IntegrationType.ValueType  # 5
    INTEGRATION_TYPE_HUGGING_FACE: _IntegrationType.ValueType  # 6

class IntegrationType(_IntegrationType, metaclass=_IntegrationTypeEnumTypeWrapper): ...

INTEGRATION_TYPE_INVALID: IntegrationType.ValueType  # 0
INTEGRATION_TYPE_JFROG: IntegrationType.ValueType  # 1
INTEGRATION_TYPE_OPSGENIE: IntegrationType.ValueType  # 2
INTEGRATION_TYPE_PAGERDUTY: IntegrationType.ValueType  # 3
INTEGRATION_TYPE_QWAK_SLACK_APP: IntegrationType.ValueType  # 4
INTEGRATION_TYPE_OPENAI: IntegrationType.ValueType  # 5
INTEGRATION_TYPE_HUGGING_FACE: IntegrationType.ValueType  # 6
global___IntegrationType = IntegrationType

class Integration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATION_ID_FIELD_NUMBER: builtins.int
    JFROG_INTEGRATION_FIELD_NUMBER: builtins.int
    OPSGENIE_INTEGRATION_FIELD_NUMBER: builtins.int
    PAGERDUTY_INTEGRATION_FIELD_NUMBER: builtins.int
    QWAK_SLACK_APP_INTEGRATION_FIELD_NUMBER: builtins.int
    OPENAI_INTEGRATION_FIELD_NUMBER: builtins.int
    HUGGING_FACE_INTEGRATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    integration_id: builtins.str
    @property
    def jfrog_integration(self) -> global___JFrogIntegration: ...
    @property
    def opsgenie_integration(self) -> qwak.integration.opsgenie_integration_pb2.OpsgenieIntegration: ...
    @property
    def pagerduty_integration(self) -> qwak.integration.pagerduty_integration_pb2.PagerdutyIntegration: ...
    @property
    def qwak_slack_app_integration(self) -> qwak.integration.slack_app_integration_pb2.SlackAppIntegration: ...
    @property
    def openai_integration(self) -> qwak.integration.open_a_i_integration_pb2.OpenAIIntegration: ...
    @property
    def hugging_face_integration(self) -> qwak.integration.hugging_face_integration_pb2.HuggingFaceIntegration: ...
    name: builtins.str
    """Integration Name"""
    def __init__(
        self,
        *,
        integration_id: builtins.str = ...,
        jfrog_integration: global___JFrogIntegration | None = ...,
        opsgenie_integration: qwak.integration.opsgenie_integration_pb2.OpsgenieIntegration | None = ...,
        pagerduty_integration: qwak.integration.pagerduty_integration_pb2.PagerdutyIntegration | None = ...,
        qwak_slack_app_integration: qwak.integration.slack_app_integration_pb2.SlackAppIntegration | None = ...,
        openai_integration: qwak.integration.open_a_i_integration_pb2.OpenAIIntegration | None = ...,
        hugging_face_integration: qwak.integration.hugging_face_integration_pb2.HuggingFaceIntegration | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hugging_face_integration", b"hugging_face_integration", "jfrog_integration", b"jfrog_integration", "openai_integration", b"openai_integration", "opsgenie_integration", b"opsgenie_integration", "pagerduty_integration", b"pagerduty_integration", "qwak_slack_app_integration", b"qwak_slack_app_integration", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hugging_face_integration", b"hugging_face_integration", "integration_id", b"integration_id", "jfrog_integration", b"jfrog_integration", "name", b"name", "openai_integration", b"openai_integration", "opsgenie_integration", b"opsgenie_integration", "pagerduty_integration", b"pagerduty_integration", "qwak_slack_app_integration", b"qwak_slack_app_integration", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["jfrog_integration", "opsgenie_integration", "pagerduty_integration", "qwak_slack_app_integration", "openai_integration", "hugging_face_integration"] | None: ...

global___Integration = Integration

class IntegrationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JFROG_INTEGRATION_SPEC_FIELD_NUMBER: builtins.int
    OPSGENIE_INTEGRATION_SPEC_FIELD_NUMBER: builtins.int
    PAGERDUTY_INTEGRATION_SPEC_FIELD_NUMBER: builtins.int
    QWAK_SLACK_APP_INTEGRATION_SPEC_FIELD_NUMBER: builtins.int
    OPENAI_INTEGRATION_SPEC_FIELD_NUMBER: builtins.int
    HUGGING_FACE_INTEGRATION_SPEC_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def jfrog_integration_spec(self) -> global___JFrogIntegrationSpec: ...
    @property
    def opsgenie_integration_spec(self) -> qwak.integration.opsgenie_integration_pb2.OpsgenieIntegrationSpec: ...
    @property
    def pagerduty_integration_spec(self) -> qwak.integration.pagerduty_integration_pb2.PagerdutyIntegrationSpec: ...
    @property
    def qwak_slack_app_integration_spec(self) -> qwak.integration.slack_app_integration_pb2.SlackAppIntegrationSpec: ...
    @property
    def openai_integration_spec(self) -> qwak.integration.open_a_i_integration_pb2.OpenAIIntegrationSpec: ...
    @property
    def hugging_face_integration_spec(self) -> qwak.integration.hugging_face_integration_pb2.HuggingFaceIntegrationSpec: ...
    name: builtins.str
    """Integration Name"""
    def __init__(
        self,
        *,
        jfrog_integration_spec: global___JFrogIntegrationSpec | None = ...,
        opsgenie_integration_spec: qwak.integration.opsgenie_integration_pb2.OpsgenieIntegrationSpec | None = ...,
        pagerduty_integration_spec: qwak.integration.pagerduty_integration_pb2.PagerdutyIntegrationSpec | None = ...,
        qwak_slack_app_integration_spec: qwak.integration.slack_app_integration_pb2.SlackAppIntegrationSpec | None = ...,
        openai_integration_spec: qwak.integration.open_a_i_integration_pb2.OpenAIIntegrationSpec | None = ...,
        hugging_face_integration_spec: qwak.integration.hugging_face_integration_pb2.HuggingFaceIntegrationSpec | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hugging_face_integration_spec", b"hugging_face_integration_spec", "jfrog_integration_spec", b"jfrog_integration_spec", "openai_integration_spec", b"openai_integration_spec", "opsgenie_integration_spec", b"opsgenie_integration_spec", "pagerduty_integration_spec", b"pagerduty_integration_spec", "qwak_slack_app_integration_spec", b"qwak_slack_app_integration_spec", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hugging_face_integration_spec", b"hugging_face_integration_spec", "jfrog_integration_spec", b"jfrog_integration_spec", "name", b"name", "openai_integration_spec", b"openai_integration_spec", "opsgenie_integration_spec", b"opsgenie_integration_spec", "pagerduty_integration_spec", b"pagerduty_integration_spec", "qwak_slack_app_integration_spec", b"qwak_slack_app_integration_spec", "spec", b"spec"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["spec", b"spec"]) -> typing_extensions.Literal["jfrog_integration_spec", "opsgenie_integration_spec", "pagerduty_integration_spec", "qwak_slack_app_integration_spec", "openai_integration_spec", "hugging_face_integration_spec"] | None: ...

global___IntegrationSpec = IntegrationSpec

class JFrogIntegration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JFROG_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def jfrog_settings(self) -> global___JFrogSettings: ...
    def __init__(
        self,
        *,
        jfrog_settings: global___JFrogSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["jfrog_settings", b"jfrog_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["jfrog_settings", b"jfrog_settings"]) -> None: ...

global___JFrogIntegration = JFrogIntegration

class JFrogIntegrationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMIN_TOKEN_FIELD_NUMBER: builtins.int
    JFROG_SETTINGS_FIELD_NUMBER: builtins.int
    admin_token: builtins.str
    """The token to use - has to had admin role in jfrog"""
    @property
    def jfrog_settings(self) -> global___JFrogSettings:
        """All user provided JFrog integration settings"""
    def __init__(
        self,
        *,
        admin_token: builtins.str = ...,
        jfrog_settings: global___JFrogSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["jfrog_settings", b"jfrog_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin_token", b"admin_token", "jfrog_settings", b"jfrog_settings"]) -> None: ...

global___JFrogIntegrationSpec = JFrogIntegrationSpec

class JFrogSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_URL_FIELD_NUMBER: builtins.int
    PYTHON_REPOSITORIES_FIELD_NUMBER: builtins.int
    HUGGINGFACE_REPOSITORY_FIELD_NUMBER: builtins.int
    ALLOW_ADDITIONAL_REPOSITORIES_FIELD_NUMBER: builtins.int
    CREATE_HUGGINGFACE_REMOTE_REPOSITORY_FIELD_NUMBER: builtins.int
    base_url: builtins.str
    """The base url to connect to"""
    @property
    def python_repositories(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of private JFrog repositories to resolve dependencies from"""
    huggingface_repository: builtins.str
    """Private HuggingFace repositories to resolve models from"""
    allow_additional_repositories: builtins.bool
    """Whether or not to allow for additional external repositories to be used, usually public repositories"""
    create_huggingface_remote_repository: builtins.bool
    """Create a HuggingFace remote repository if it doesn't exist"""
    def __init__(
        self,
        *,
        base_url: builtins.str = ...,
        python_repositories: collections.abc.Iterable[builtins.str] | None = ...,
        huggingface_repository: builtins.str = ...,
        allow_additional_repositories: builtins.bool = ...,
        create_huggingface_remote_repository: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_additional_repositories", b"allow_additional_repositories", "base_url", b"base_url", "create_huggingface_remote_repository", b"create_huggingface_remote_repository", "huggingface_repository", b"huggingface_repository", "python_repositories", b"python_repositories"]) -> None: ...

global___JFrogSettings = JFrogSettings

class IntegrationValidationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JFROG_VALIDATION_SPEC_FIELD_NUMBER: builtins.int
    OPSGENIE_VALIDATION_SPEC_FIELD_NUMBER: builtins.int
    PAGERDUTY_VALIDATION_SPEC_FIELD_NUMBER: builtins.int
    QWAK_SLACK_APP_VALIDATION_SPEC_FIELD_NUMBER: builtins.int
    OPENAI_VALIDATION_SPEC_FIELD_NUMBER: builtins.int
    HUGGING_FACE_VALIDATION_SPEC_FIELD_NUMBER: builtins.int
    @property
    def jfrog_validation_spec(self) -> global___JFrogValidationSpec: ...
    @property
    def opsgenie_validation_spec(self) -> qwak.integration.opsgenie_integration_pb2.OpsgenieValidationSpec: ...
    @property
    def pagerduty_validation_spec(self) -> qwak.integration.pagerduty_integration_pb2.PagerdutyValidationSpec: ...
    @property
    def qwak_slack_app_validation_spec(self) -> qwak.integration.slack_app_integration_pb2.SlackAppValidationSpec: ...
    @property
    def openai_validation_spec(self) -> qwak.integration.open_a_i_integration_pb2.OpenAIValidationSpec: ...
    @property
    def hugging_face_validation_spec(self) -> qwak.integration.hugging_face_integration_pb2.HuggingFaceValidationSpec: ...
    def __init__(
        self,
        *,
        jfrog_validation_spec: global___JFrogValidationSpec | None = ...,
        opsgenie_validation_spec: qwak.integration.opsgenie_integration_pb2.OpsgenieValidationSpec | None = ...,
        pagerduty_validation_spec: qwak.integration.pagerduty_integration_pb2.PagerdutyValidationSpec | None = ...,
        qwak_slack_app_validation_spec: qwak.integration.slack_app_integration_pb2.SlackAppValidationSpec | None = ...,
        openai_validation_spec: qwak.integration.open_a_i_integration_pb2.OpenAIValidationSpec | None = ...,
        hugging_face_validation_spec: qwak.integration.hugging_face_integration_pb2.HuggingFaceValidationSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hugging_face_validation_spec", b"hugging_face_validation_spec", "jfrog_validation_spec", b"jfrog_validation_spec", "openai_validation_spec", b"openai_validation_spec", "opsgenie_validation_spec", b"opsgenie_validation_spec", "pagerduty_validation_spec", b"pagerduty_validation_spec", "qwak_slack_app_validation_spec", b"qwak_slack_app_validation_spec", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hugging_face_validation_spec", b"hugging_face_validation_spec", "jfrog_validation_spec", b"jfrog_validation_spec", "openai_validation_spec", b"openai_validation_spec", "opsgenie_validation_spec", b"opsgenie_validation_spec", "pagerduty_validation_spec", b"pagerduty_validation_spec", "qwak_slack_app_validation_spec", b"qwak_slack_app_validation_spec", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["jfrog_validation_spec", "opsgenie_validation_spec", "pagerduty_validation_spec", "qwak_slack_app_validation_spec", "openai_validation_spec", "hugging_face_validation_spec"] | None: ...

global___IntegrationValidationSpec = IntegrationValidationSpec

class JFrogValidationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMIN_TOKEN_FIELD_NUMBER: builtins.int
    BASE_URL_FIELD_NUMBER: builtins.int
    admin_token: builtins.str
    """The token to use - has to had admin role in jfrog"""
    base_url: builtins.str
    """The base url to connect to"""
    def __init__(
        self,
        *,
        admin_token: builtins.str = ...,
        base_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin_token", b"admin_token", "base_url", b"base_url"]) -> None: ...

global___JFrogValidationSpec = JFrogValidationSpec

class IntegrationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JFROG_INTEGRATION_OPTIONS_FIELD_NUMBER: builtins.int
    OPSGENIE_INTEGRATION_OPTIONS_FIELD_NUMBER: builtins.int
    PAGERDUTY_INTEGRATION_OPTIONS_FIELD_NUMBER: builtins.int
    QWAK_SLACK_APP_INTEGRATION_OPTIONS_FIELD_NUMBER: builtins.int
    OPENAI_INTEGRATION_OPTIONS_FIELD_NUMBER: builtins.int
    HUGGING_FACE_INTEGRATION_OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def jfrog_integration_options(self) -> global___JFrogIntegrationOptions:
        """Options for jfrog integration"""
    @property
    def opsgenie_integration_options(self) -> qwak.integration.opsgenie_integration_pb2.OpsgenieIntegrationOptions: ...
    @property
    def pagerduty_integration_options(self) -> qwak.integration.pagerduty_integration_pb2.PagerdutyIntegrationOptions: ...
    @property
    def qwak_slack_app_integration_options(self) -> qwak.integration.slack_app_integration_pb2.SlackAppIntegrationOptions: ...
    @property
    def openai_integration_options(self) -> qwak.integration.open_a_i_integration_pb2.OpenAIIntegrationOptions: ...
    @property
    def hugging_face_integration_options(self) -> qwak.integration.hugging_face_integration_pb2.HuggingFaceIntegrationOptions: ...
    def __init__(
        self,
        *,
        jfrog_integration_options: global___JFrogIntegrationOptions | None = ...,
        opsgenie_integration_options: qwak.integration.opsgenie_integration_pb2.OpsgenieIntegrationOptions | None = ...,
        pagerduty_integration_options: qwak.integration.pagerduty_integration_pb2.PagerdutyIntegrationOptions | None = ...,
        qwak_slack_app_integration_options: qwak.integration.slack_app_integration_pb2.SlackAppIntegrationOptions | None = ...,
        openai_integration_options: qwak.integration.open_a_i_integration_pb2.OpenAIIntegrationOptions | None = ...,
        hugging_face_integration_options: qwak.integration.hugging_face_integration_pb2.HuggingFaceIntegrationOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hugging_face_integration_options", b"hugging_face_integration_options", "jfrog_integration_options", b"jfrog_integration_options", "openai_integration_options", b"openai_integration_options", "opsgenie_integration_options", b"opsgenie_integration_options", "pagerduty_integration_options", b"pagerduty_integration_options", "qwak_slack_app_integration_options", b"qwak_slack_app_integration_options", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hugging_face_integration_options", b"hugging_face_integration_options", "jfrog_integration_options", b"jfrog_integration_options", "openai_integration_options", b"openai_integration_options", "opsgenie_integration_options", b"opsgenie_integration_options", "pagerduty_integration_options", b"pagerduty_integration_options", "qwak_slack_app_integration_options", b"qwak_slack_app_integration_options", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["jfrog_integration_options", "opsgenie_integration_options", "pagerduty_integration_options", "qwak_slack_app_integration_options", "openai_integration_options", "hugging_face_integration_options"] | None: ...

global___IntegrationOptions = IntegrationOptions

class JFrogIntegrationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AVAILABLE_PRIVATE_PYTHON_REPOSITORIES_FIELD_NUMBER: builtins.int
    AVAILABLE_PRIVATE_HUGGINGFACE_REPOSITORIES_FIELD_NUMBER: builtins.int
    @property
    def available_private_python_repositories(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JfrogRepository]:
        """available private python repositories in the Jfrog account"""
    @property
    def available_private_huggingface_repositories(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JfrogRepository]:
        """available private huggingface repositories in the Jfrog account"""
    def __init__(
        self,
        *,
        available_private_python_repositories: collections.abc.Iterable[global___JfrogRepository] | None = ...,
        available_private_huggingface_repositories: collections.abc.Iterable[global___JfrogRepository] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["available_private_huggingface_repositories", b"available_private_huggingface_repositories", "available_private_python_repositories", b"available_private_python_repositories"]) -> None: ...

global___JFrogIntegrationOptions = JFrogIntegrationOptions

class JfrogRepository(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___JfrogRepository = JfrogRepository

class ValidationIntegrationResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_SUCCESSFUL_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    is_successful: builtins.bool
    """Is the validation successful"""
    @property
    def options(self) -> global___IntegrationOptions:
        """The integration options after it validate"""
    error_message: builtins.str
    """The error if validation failed"""
    def __init__(
        self,
        *,
        is_successful: builtins.bool = ...,
        options: global___IntegrationOptions | None = ...,
        error_message: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["error_message", b"error_message", "is_successful", b"is_successful", "options", b"options"]) -> None: ...

global___ValidationIntegrationResult = ValidationIntegrationResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class DataCatalogConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GLUE_FIELD_NUMBER: builtins.int
    BIG_LAKE_FIELD_NUMBER: builtins.int
    UNITY_CATALOG_FIELD_NUMBER: builtins.int
    @property
    def glue(self) -> global___GlueConfiguration: ...
    @property
    def big_lake(self) -> global___BigLakeConfiguration: ...
    @property
    def unity_catalog(self) -> global___UnityCatalogConfiguration: ...
    def __init__(
        self,
        *,
        glue: global___GlueConfiguration | None = ...,
        big_lake: global___BigLakeConfiguration | None = ...,
        unity_catalog: global___UnityCatalogConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["big_lake", b"big_lake", "glue", b"glue", "type", b"type", "unity_catalog", b"unity_catalog"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["big_lake", b"big_lake", "glue", b"glue", "type", b"type", "unity_catalog", b"unity_catalog"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["glue", "big_lake", "unity_catalog"] | None: ...

global___DataCatalogConfiguration = DataCatalogConfiguration

class BigLakeConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    BIG_LAKE_CONNECTION_NAME_FIELD_NUMBER: builtins.int
    BIG_LAKE_LOCATION_FIELD_NUMBER: builtins.int
    CATALOG_NAME_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    big_lake_connection_name: builtins.str
    big_lake_location: builtins.str
    catalog_name: builtins.str
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        big_lake_connection_name: builtins.str = ...,
        big_lake_location: builtins.str = ...,
        catalog_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["big_lake_connection_name", b"big_lake_connection_name", "big_lake_location", b"big_lake_location", "catalog_name", b"catalog_name", "project_id", b"project_id"]) -> None: ...

global___BigLakeConfiguration = BigLakeConfiguration

class GlueConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GlueConfiguration = GlueConfiguration

class UnityCatalogConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATALOG_NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    catalog_name: builtins.str
    url: builtins.str
    def __init__(
        self,
        *,
        catalog_name: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_name", b"catalog_name", "url", b"url"]) -> None: ...

global___UnityCatalogConfiguration = UnityCatalogConfiguration



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/object_storage_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHqwak/administration/runtime_configuration/v0/object_storage_config.proto\x12\x42qwak.administration.runtime_configuration.v0.object_storage_config\"\xe4\x02\n\x1aObjectStorageConfiguration\x12\x61\n\x02s3\x18\x01 \x01(\x0b\x32S.qwak.administration.runtime_configuration.v0.object_storage_config.S3ConfigurationH\x00\x12\x61\n\x02gs\x18\x02 \x01(\x0b\x32S.qwak.administration.runtime_configuration.v0.object_storage_config.GSConfigurationH\x00\x12x\n\x12\x61zure_blob_storage\x18\x03 \x01(\x0b\x32Z.qwak.administration.runtime_configuration.v0.object_storage_config.AzureBlobConfigurationH\x00\x42\x06\n\x04type\"!\n\x0fS3Configuration\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\"!\n\x0fGSConfiguration\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\"V\n\x16\x41zureBlobConfiguration\x12\x1c\n\x14storage_account_name\x18\x01 \x01(\t\x12\x1e\n\x16storage_container_name\x18\x02 \x01(\tB\xe2\x01\n;com.jfrog.ml.runtime_configuration.v0.object_storage_configP\x01Z\xa0\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.runtime_configuration.v0.object_storage_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n;com.jfrog.ml.runtime_configuration.v0.object_storage_configP\001Z\240\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0'
  _globals['_OBJECTSTORAGECONFIGURATION']._serialized_start=145
  _globals['_OBJECTSTORAGECONFIGURATION']._serialized_end=501
  _globals['_S3CONFIGURATION']._serialized_start=503
  _globals['_S3CONFIGURATION']._serialized_end=536
  _globals['_GSCONFIGURATION']._serialized_start=538
  _globals['_GSCONFIGURATION']._serialized_end=571
  _globals['_AZUREBLOBCONFIGURATION']._serialized_start=573
  _globals['_AZUREBLOBCONFIGURATION']._serialized_end=659
# @@protoc_insertion_point(module_scope)
